@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Adrian Dusa
+# Copyright (c) 2019, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -83,7 +83,7 @@ function(noflevels, ...) {
             }
         }
     }
-    return(.Call("createMatrix", tosend, PACKAGE = "QCA"))
+    return(.Call("C_createMatrix", tosend, PACKAGE = "QCA"))
     pwr <- unique(noflevels)
     if (length(pwr) == 1) {
         create <- function(idx) {
