@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Adrian Dusa
+# Copyright (c) 2019, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -58,7 +58,17 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
         }
     }
     missingdata <- missing(data)
-    if (!is.character(setms)) {
+    if (is.character(setms)) {
+        if (setms == tolower(setms) & setms != toupper(setms)) {
+            if (eval.parent(parse(text = sprintf("is.element(\"%s\", ls())", toupper(setms))), n = 1)) {
+                conds <- toupper(setms)
+                setms <- eval.parent(parse(text = sprintf("get(\"%s\")", toupper(setms))), n = 1)
+                setms <- QCA::getLevels(setms) - setms - 1
+                condnegated <- TRUE
+            }
+        }
+    }
+    else {
         if (inherits(testit <- tryCatch(eval(setms), error = function(e) e), "error")) {
             setms <- deparse(funargs$setms)
         }
@@ -68,7 +78,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                 if (hastilde(testit)) {
                     if (eval.parent(parse(text = sprintf("is.element(\"%s\", ls())", notilde(testit))), n = 1)) {
                         setms <- eval.parent(parse(text = sprintf("get(\"%s\")", notilde(testit))), n = 1)
-                        setms <- getNoflevels(setms) - setms - 1
+                        setms <- QCA::getLevels(setms) - setms - 1
                         condnegated <- TRUE
                     }
                     else {
@@ -78,16 +88,6 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             }
         }
     }
-    else {
-        if (setms == tolower(setms) & setms != toupper(setms)) {
-            if (eval.parent(parse(text = sprintf("is.element(\"%s\", ls())", toupper(setms))), n = 1)) {
-                conds <- toupper(setms)
-                setms <- eval.parent(parse(text = sprintf("get(\"%s\")", toupper(setms))), n = 1)
-                setms <- getNoflevels(setms) - setms - 1
-                condnegated <- TRUE
-            }
-        }
-    }
     outcomename <- ""
     outnegated <- NULL
     if (inherits(tryCatch(eval(outcome), error = function(e) e), "error")) {
@@ -104,7 +104,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                 if (hastilde(testit)) {
                     if (eval.parent(parse(text = sprintf("is.element(\"%s\", ls())", notilde(testit))), n = 1)) {
                         outcome <- eval.parent(parse(text = sprintf("get(\"%s\")", notilde(testit))), n = 1)
-                        outcome <- getNoflevels(outcome) - outcome - 1
+                        outcome <- QCA::getLevels(outcome) - outcome - 1
                         outnegated <- TRUE
                     }
                     else {
@@ -134,7 +134,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             ica <- other.args$incl.cut0
         }
     syscalls <- unlist(lapply(lapply(sys.calls(), as.character), "[[", 1)) 
-    force.rows <- "force.rows" %in% names(other.args)
+    force.rows <- is.element("force.rows", names(other.args))
     if (is.null(outnegated)) {
         outnegated <- identical(substr(gsub("[[:space:]]", "", funargs$outcome), 1, 2), "1-")
     }
@@ -158,7 +158,6 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             if (is.element("data.frame", class(data))) {
                 data <- as.data.frame(data)
             }
-            verify.qca(data)
             colnames(data) <- toupper(colnames(data))
             for (i in colnames(data)) {
                 if (!is.numeric(data[, i])) {
@@ -223,7 +222,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                 else {
                     if (is.character(outcome)) {
                         conditions <- setdiff(conditions, outcome)
-                        if (! toupper(notilde(curlyBrackets(outcome, outside=TRUE))) %in% colnames(data)) {
+                        if (!is.element(toupper(notilde(curlyBrackets(outcome, outside = TRUE))), colnames(data))) {
                             cat("\n")
                             stop(simpleError("The outcome in the expression is not found in the data.\n\n"))
                         }
@@ -239,19 +238,27 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                         outcome <- curlyBrackets(outcome, outside=TRUE)
                         data[, toupper(outcome)] <- as.numeric(data[, toupper(outcome)] %in% splitstr(outcome.value))
                     }
-                    else if (! outcome %in% colnames(data)) {
-                        data[, toupper(outcome)] <- getNoflevels(data[, toupper(outcome)]) - data[, toupper(outcome)] - 1
+                    else if (!is.element(outcome, colnames(data))) {
+                        if (!is.element(outcome, c(tolower(outcome), toupper(outcome)))) {
+                            cat("\n")
+                            stop(simpleError("The outcome name should not contain both lower and upper case letters.\n\n"))
+                        }
+                        data[, toupper(outcome)] <- QCA::getLevels(data[, toupper(outcome)]) - data[, toupper(outcome)] - 1
                     }
                     outcome <- toupper(outcome)
                 }
                 complete <- FALSE
-                if ("complete" %in% names(other.args)) {
+                if (is.element("complete", names(other.args))) {
                     if (is.logical(other.args$complete)) {
                         complete <- other.args$complete
                     }
                 }
                 if (is.character(outcome)) {
+                    verify.qca(data[, which(colnames(data) == outcome), drop = FALSE])
                     data2 <- data[, -which(colnames(data) == outcome), drop = FALSE]
+                    texp <- translate(expression, data = data2)
+                    data2 <- data2[, apply(texp, 2, function(x) any(x >= 0)), drop = FALSE]
+                    verify.qca(data2)
                     setms <- compute(expression, data2, separate = TRUE)
                     if (is.data.frame(setms)) {
                         setms$expression <- compute(expression, data2)
@@ -261,6 +268,9 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                     }
                 }
                 else {
+                    texp <- translate(expression, data = data)
+                    data <- data[, apply(texp, 2, function(x) any(x >= 0)), drop = FALSE]
+                    verify.qca(data)
                     setms <- compute(expression, data, separate = TRUE)
                     if (is.data.frame(setms)) {
                         setms$expression <- compute(expression, data)
@@ -292,14 +302,14 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
                     neg.out <- TRUE
                     outcome <- gsub("1-", "", gsub("[[:space:]]|\"", "", funargs$outcome))
                 }
-                if (! toupper(curlyBrackets(outcome, outside = TRUE)) %in% colnames(data)) {
+                if (!is.element(toupper(curlyBrackets(outcome, outside = TRUE)), colnames(data))) {
                     cat("\n")
                     stop(simpleError("Inexisting outcome name.\n\n"))
                 }
                 if (grepl("[{|}]", outcome)) {
                     outcome.value <- curlyBrackets(outcome)
                     outcome <- curlyBrackets(outcome, outside=TRUE)
-                    data[, toupper(outcome)] <- as.numeric(data[, toupper(outcome)] %in% splitstr(outcome.value))
+                    data[, toupper(outcome)] <- is.element(data[, toupper(outcome)], splitstr(outcome.value)) * 1
                 }
                 outcomename <- toupper(outcome)
                 outcome <- data[, outcomename]
@@ -320,6 +330,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             stop(simpleError("The relationship should be either \"necessity\" or \"sufficiency\".\n\n"))
         }
         if (!missing(data)) {
+            verify.qca(data) 
             if (length(outcome) != nrow(data)) {
                 cat("\n")
                 stop(simpleError("The outcome's length should be the same as the number of rows in the data.\n\n"))
@@ -469,7 +480,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             }
             if (is.null(rownames(setms))) {
                 use.tilde <- FALSE
-                if ("use.tilde" %in% names(other.args)) {
+                if (is.element("use.tilde", names(other.args))) {
                     use.tilde <- other.args$use.tilde
                 }
                 rownames(setms) <- writePrimeimp(setms, mv = any(setms > 2), use.tilde = use.tilde)
@@ -483,7 +494,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             }
         }
         if (neg.out) {
-            outcome <- getNoflevels(outcome) - outcome - 1
+            outcome <- QCA::getLevels(outcome) - outcome - 1
         }
         sum.outcome <- sum(outcome)
         if (pims) {
@@ -522,7 +533,7 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
         mins <- as.data.frame(mins)
         colnames(mins) <- conditions
     }
-    colnames(mins) <- gsub("[[:space:]|,]", "", colnames(mins))
+    colnames(mins) <- gsub("[[:space:]]", "", colnames(mins))
     multivalue <- any(grepl("[{|}]", colnames(mins)))
     if (condnegated) {
         if (identical(conds, "")) {
